@@ -21,7 +21,7 @@ class AdsApi:
     lock: Lock = mp.Lock()
 
     def request(self, endpoint: str, params: dict | None = None, data: dict | None = None, attempts: int = 5, method:str = 'GET', json:dict = None):
-        req_info = f'request {self.base_url_ads+endpoint}\n data = {data}\n params = {params}\n'
+        req_info = f'request {self.base_url_ads+endpoint}\n data = {data}\n params = {params}\njson={json}\n'
         for attempt in range(attempts):
             try:
                 self.lock.acquire()
