@@ -44,4 +44,4 @@ class FingepringConfig(BaseModel):
     speech_switch: int = 1
     mac_address_config: dict = {"model": "1", "address": ""}
     browser_kernel_config: dict = {"version": "latest", "type": "chrome"}
-    gpu: int = 0
+    gpu: str = 0
